@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,6 +26,8 @@ Autocomplete Handler for People
 
 from __future__ import unicode_literals, absolute_import
 
+from sqlalchemy import orm
+
 from rattail.autocomplete import Autocompleter
 from rattail.autocomplete.base import PhoneMagicMixin
 from rattail.db import model
@@ -73,3 +75,27 @@ class PersonNewOrderAutocompleter(PhoneMagicMixin, Autocompleter):
     model_class = model.Person
     autocomplete_fieldname = 'display_name'
     phone_model_class = model.PersonPhoneNumber
+
+    def make_base_query(self, session):
+        query = super(PersonNewOrderAutocompleter, self).make_base_query(session)
+        return query.options(orm.joinedload(self.model_class.emails))
+
+    def get_autocomplete_results(self, data):
+        results = []
+        for contact in data:
+            name = contact.display_name
+
+            values = [name]
+
+            phone = contact.first_phone()
+            if phone:
+                values.append(phone.number)
+
+            email = contact.first_email()
+            if email:
+                values.append(email.address)
+
+            results.append({'value': contact.uuid,
+                            'label': ' / '.join(values),
+                            'display': name})
+        return results
