@@ -96,6 +96,10 @@ class BatchHandler(object):
         """
         return self.batch_model_class.batch_key
 
+    @classmethod
+    def get_spec(cls):
+        return '{}:{}'.format(cls.__module__, cls.__name__)
+
     def get_model_title(self):
         return self.batch_model_class.get_model_title()
 
