@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -46,6 +46,16 @@ class PricingBatchHandler(BatchHandler):
     # cached decimal object used for rounding percentages, below
     percent_decimal = decimal.Decimal('.001')
 
+    def allow_future(self):
+        """
+        Returns boolean indicating whether "future" price changes
+        should be allowed.
+
+        :returns: ``True`` if future price changes allowed; else ``False``.
+        """
+        return self.config.getbool('rattail.batch', 'pricing.allow_future',
+                                   default=False)
+
     def should_populate(self, batch):
         if batch.params and batch.params.get('auto_generate_from_srp_breach'):
             return True
