@@ -1122,7 +1122,7 @@ class RunAndMail(Subcommand):
             log.warning("command exited with code: %s", retcode)
 
         if six.PY3:
-            output = output.decode('ascii')
+            output = output.decode(errors='replace')
 
         run_ended = make_utc()
         runtime = run_ended - run_began
