@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -76,7 +76,7 @@ class KeheCatalogParser(CatalogParser):
 
         for r in range(1, sheet.nrows): # Skip first header row.
 
-            row = model.VendorCatalogRow()
+            row = model.VendorCatalogBatchRow()
             upc = sheet.cell_value(r, 5) or None
             row.upc = GPC(int(upc)) if upc else None
             row.brand_name = sheet.cell_value(r, 1)
