@@ -652,6 +652,10 @@ def consume_changes_from(config, session, consumer, obtained):
                 })
                 return False
 
+            else: # more attempts to be made, but log error for debug
+                log.debug("attempt #%s failed calling `consumer.process_changes()`",
+                          attempts, exc_info=True)
+
             # if this exception is not the first, and is of a different type
             # than seen previously, do *not* continue to retry
             if errtype is not None and not isinstance(errobj, errtype):
