@@ -141,16 +141,27 @@ class RattailWatcher(DataSyncWatcher):
     def prune_changes(self, keys):
         model = self.model
         deleted = 0
-        session = self.app.make_session(bind=self.engine)
-        for key in keys:
-            if key: # note that key can sometimes be None
-                change = session.query(model.Change).get(key)
-                if change:
-                    session.delete(change)
-                    session.flush()
-                    deleted += 1
-        session.commit()
-        session.close()
+        try:
+            session = self.app.make_session(bind=self.engine)
+        except:
+            log.exception("failed to make session for pruning changes")
+            raise
+        try:
+            for key in keys:
+                if key: # note that key can sometimes be None
+                    change = session.query(model.Change).get(key)
+                    if change:
+                        session.delete(change)
+                        session.flush()
+                        deleted += 1
+        except:
+            log.exception("failed to prune changes")
+            session.rollback()
+            raise
+        else:
+            session.commit()
+        finally:
+            session.close()
         return deleted
 
 
@@ -433,11 +444,9 @@ class FromRattailToRattailExportConsumer(FromRattailToRattailBase):
     def rollback_transaction(self):
         self.target_session.rollback()
         self.target_session.close()
-        del self.target_session
 
         self.local_session.rollback()
         self.local_session.close()
-        del self.local_session
 
     def commit_transaction(self):
         # TODO: should we ever commit local?
