@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -58,6 +58,10 @@ class PricingBatch(BatchMixin, Base):
     manually priced under normal circumstances.
     """)
 
+    start_date = sa.Column(sa.Date(), nullable=True, doc="""
+    Start date for prices within the batch.
+    """)
+
     input_filename = filename_column(nullable=True, doc="""
     Base name of the input data file, if applicable.
     """)
