@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -32,7 +32,7 @@ import getpass
 import warnings
 import logging
 
-from rattail.config import parse_list
+from rattail.config import parse_list, ConfigProfileAction
 from rattail.util import load_object
 from rattail.exceptions import ConfigurationError
 from rattail.filemon.actions import CommandAction
@@ -41,46 +41,8 @@ from rattail.filemon.actions import CommandAction
 log = logging.getLogger(__name__)
 
 
-class ProfileAction(object):
-    """
-    Simple class to hold configuration for a particular action defined within a
-    monitor :class:`Profile`.  Each instance has the following attributes:
-
-    .. attribute:: spec
-
-       The original "spec" string used to obtain the action callable.
-
-    .. attribute:: action
-
-       A reference to the action callable.
-
-    .. attribute:: args
-
-       A sequence of positional arguments to be passed to the callable (in
-       addition to the file path) when invoking the action.
-
-    .. attribute:: kwargs
-
-       A dictionary of keyword arguments to be passed to the callable (in
-       addition to the positional arguments) when invoking the action.
-
-    .. attribute:: retry_attempts
-
-       Number of attempts to make when invoking the action.  Defaults to ``1``,
-       meaning the first attempt will be made but no retries will happen.
-
-    .. attribute:: retry_delay
-
-       Number of seconds to pause between retry attempts, if
-       :attr:`retry_attempts` is greater than one.  Defaults to ``0``.
-    """
-
-    spec = None
-    action = None
-    args = []
-    kwargs = {}
-    retry_attempts = 1
-    retry_delay = 0
+# TODO: deprecate / remove this
+ProfileAction = ConfigProfileAction
 
 
 class Profile(object):
@@ -151,8 +113,9 @@ class Profile(object):
 
     .. attribute:: actions
 
-       List of :class:`ProfileAction` instances representing the actions to be
-       invoked when new files are discovered.
+       List of :class:`~rattail.config.ConfigProfileAction` instances
+       representing the actions to be invoked when new files are
+       discovered.
     """
 
     def __init__(self, config, key):
@@ -176,8 +139,9 @@ class Profile(object):
 
     def _config_action(self, name):
         """
-        Retrieve an "action" value from config, for the current profile.  This
-        returns a :class:`ProfileAction` instance.
+        Retrieve an "action" value from config, for the current
+        profile.  This returns a
+        :class:`~rattail.config.ConfigProfileAction` instance.
         """
         function = self._config_string('action.{}.func'.format(name))
         class_ = self._config_string('action.{}.class'.format(name))
@@ -189,7 +153,7 @@ class Profile(object):
                 "File monitor profile '{}' (action '{}') must have exactly one of: "
                 "function, class, command".format(self.key, name))
 
-        action = ProfileAction()
+        action = ConfigProfileAction()
         action.config = self.config
 
         if function:
