@@ -39,7 +39,7 @@ from rattail.db import api
 from rattail.util import load_object
 from rattail.app import GenericHandler
 from rattail.gpc import GPC
-from rattail.barcodes import upce_to_upca
+from rattail.barcodes import upce_to_upca, upc_check_digit
 
 
 log = logging.getLogger(__name__)
@@ -123,6 +123,36 @@ class ProductsHandler(GenericHandler):
 
         return make_full_description(brand_name, description, size)
 
+    def upc_check_digits_needed(self, values):
+        """
+        Figure out whether the given UPC-ish values need to have check
+        digits calculated, or if they're already present.
+
+        In practice what this does, is look for any values which *are*
+        in need of a check digit.  If any are found, it will be
+        assumed that "all" values need a check digit.
+
+        :param values: Sequence of UPC-ish values.  Each value is
+           assumed to be a string.
+
+        :returns: Boolean; ``True`` means check digits need to be
+           calculated for each value; ``False`` means check digits are
+           already present.
+        """
+        for value in values:
+
+            # assuming the last char in string is the check digit, we
+            # calculate again based on all but last char.  if *not* a
+            # match, then this value needs a check digit!
+            data = value[:-1]
+            check = value[-1]
+            calculated = upc_check_digit(data)
+            if check != calculated:
+                return True
+
+        # no check digits needed
+        return False
+
     # TODO: deprecate / remove (afaik it is not being used?)
     def find_products_by_key(self, session, value, **kwargs):
         """
