@@ -82,6 +82,55 @@ class TransactionImporter(ToTrainwreck):
                     .filter(time_field < self.app.make_utc(self.end_time))
 
 
+class TransactionOrderMarkerImporter(ToTrainwreck):
+    """
+    Transaction order marker data importer
+
+    .. attribute:: match_on_time_field
+
+       This time field will be used for the cache query etc.  In
+       particular it controls which transactions are deemed to belong
+       to a given date, which is needed when restricting the import to
+       a particular date range.  Can set this to ``'upload_time'`` or
+       ``'start_time'`` if necessary, depending on the nature of
+       transaction data coming from the host side.
+    """
+    match_on_time_field = 'end_time'
+
+    @property
+    def importing_from_system(self):
+        raise NotImplementedError("TODO: please define this for your subclass")
+
+    def get_model_class(self):
+        if hasattr(self, 'model_class') and self.model_class:
+            return self.model_class
+        trainwreck = self.config.get_trainwreck_model()
+        return trainwreck.TransactionOrderMarker
+
+    @property
+    def transaction_class(self):
+        trainwreck = self.config.get_trainwreck_model()
+        return trainwreck.Transaction
+
+    def cache_query(self):
+        query = super(TransactionOrderMarkerImporter, self).cache_query()
+        trainwreck = self.config.get_trainwreck_model()
+
+        query = query.join(trainwreck.Transaction)
+
+        try:
+            system = self.importing_from_system
+        except NotImplementedError:
+            pass
+        else:
+            query = query.filter(trainwreck.Transaction.system == system)
+
+        time_field = getattr(trainwreck.Transaction, self.match_on_time_field)
+        query = query.filter(time_field >= self.app.make_utc(self.start_time))\
+                     .filter(time_field < self.app.make_utc(self.end_time))
+        return query
+
+
 class TransactionItemImporter(ToTrainwreck):
     """
     Transaction item data importer
