@@ -159,6 +159,26 @@ def import_module_path(module_path):
     return last_module(module, module_path)
 
 
+def import_reload(module):
+    """
+    Reload a module.
+
+    :param module: An already-loaded module.
+
+    :returns: The module.
+    """
+    if six.PY3:
+        try:
+            import importlib
+        except ImportError:
+            pass
+        else:
+            return importlib.reload(module)
+
+    # fingers crossed we're on py2
+    return reload(module)
+
+
 def get_object_spec(obj):
     """
     Returns the "object spec" string for the given object.
